==> rax-1.0.8.tgz: package/lib/devtools/index.js <==
"use strict";

var _instance = _interopRequireDefault(require("../vdom/instance"));

var _host = _interopRequireDefault(require("../vdom/host"));

var _reconciler = _interopRequireDefault(require("./reconciler"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var renderer = {
  ComponentTree: {
    getClosestInstanceFromNode: function getClosestInstanceFromNode(node) {
      return _instance.default.get(node);
    },
    getNodeFromInstance: function getNodeFromInstance(inst) {
      // inst is an internal instance (but could be a composite)
      while (inst._renderedComponent) {
        inst = inst._renderedComponent;
      }

      if (inst) {
        return inst._nativeNode;
      } else {
        return null;
      }
    }
  },
  Mount: {
    get _instancesByReactRootID() {
      var rootComponents = {}; // Ignore display top-level root component

      for (var rootID in _host.default.rootComponents) {
        rootComponents[rootID] = _host.default.rootComponents[rootID]._renderedComponent;
      }

      return rootComponents;
    },

    _renderNewRootComponent: _reconciler.default.renderNewRootComponent
  },
  Reconciler: _reconciler.default,
  // monitor the info of all components
  monitor: null
};
/* global __REACT_DEVTOOLS_GLOBAL_HOOK__ */

if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ !== 'undefined' && typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.inject === 'function') {
  __REACT_DEVTOOLS_GLOBAL_HOOK__.inject(renderer);
}

==> rax-1.0.11.tgz: package/lib/devtools/index.js <==
"use strict";

var _instance = _interopRequireDefault(require("../vdom/instance"));

var _host = _interopRequireDefault(require("../vdom/host"));

var _reconciler = _interopRequireDefault(require("./reconciler"));

var _constant = require("../constant");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var renderer = {
  ComponentTree: {
    getClosestInstanceFromNode: function getClosestInstanceFromNode(node) {
      return _instance.default.get(node);
    },
    getNodeFromInstance: function getNodeFromInstance(inst) {
      // inst is an internal instance (but could be a composite)
      while (inst[_constant.RENDERED_COMPONENT]) {
        inst = inst[_constant.RENDERED_COMPONENT];
      }

      if (inst) {
        return inst._nativeNode;
      } else {
        return null;
      }
    }
  },
  Mount: {
    get _instancesByReactRootID() {
      var rootComponents = {}; // Ignore display top-level root component

      for (var rootID in _host.default.rootComponents) {
        rootComponents[rootID] = _host.default.rootComponents[rootID][_constant.RENDERED_COMPONENT];
      }

      return rootComponents;
    },

    _renderNewRootComponent: _reconciler.default.renderNewRootComponent
  },
  Reconciler: _reconciler.default,
  // monitor the info of all components
  monitor: null
};
/* global __REACT_DEVTOOLS_GLOBAL_HOOK__ */

if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ !== 'undefined' && typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.inject === 'function') {
  __REACT_DEVTOOLS_GLOBAL_HOOK__.inject(renderer);
}
